pub struct FfiGroupData {
pub id: String,
pub name: String,
pub description: Option<String>,
pub picture: Option<String>,
pub members: Vec<String>,
pub admins: Vec<String>,
pub created_at_ms: u64,
pub secret: Option<String>,
pub accepted: Option<bool>,
}Expand description
FFI-friendly group metadata payload.
Fields
id: Stringname: Stringdescription: Option<String>picture: Option<String>members: Vec<String>admins: Vec<String>created_at_ms: u64secret: Option<String>accepted: Option<bool>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for FfiGroupData
impl<UT> ConvertError<UT> for FfiGroupData
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for FfiGroupData
impl<UT> FfiConverter<UT> for FfiGroupData
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for FfiGroupData
impl<UT> Lift<UT> for FfiGroupData
Sourceimpl<UT> LiftRef<UT> for FfiGroupData
impl<UT> LiftRef<UT> for FfiGroupData
type LiftType = FfiGroupData
Sourceimpl<UT> LiftReturn<UT> for FfiGroupData
impl<UT> LiftReturn<UT> for FfiGroupData
Sourcetype ReturnType = <FfiGroupData as Lift<UT>>::FfiType
type ReturnType = <FfiGroupData as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for FfiGroupData
impl<UT> Lower<UT> for FfiGroupData
type FfiType = <FfiGroupData as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for FfiGroupData
impl<UT> LowerError<UT> for FfiGroupData
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for FfiGroupData
impl<UT> LowerReturn<UT> for FfiGroupData
Sourcetype ReturnType = <FfiGroupData as Lower<UT>>::FfiType
type ReturnType = <FfiGroupData as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for FfiGroupData
impl<UT> TypeId<UT> for FfiGroupData