pub struct GroupDecryptedResult {
pub group_id: String,
pub sender_event_pubkey_hex: String,
pub sender_device_pubkey_hex: String,
pub sender_owner_pubkey_hex: Option<String>,
pub outer_event_id: String,
pub outer_created_at: u64,
pub key_id: u32,
pub message_number: u32,
pub inner_event_json: String,
pub inner_event_id: String,
}Expand description
Decrypted group event returned by GroupManager.
Fields
group_id: Stringsender_event_pubkey_hex: Stringsender_device_pubkey_hex: Stringsender_owner_pubkey_hex: Option<String>outer_event_id: Stringouter_created_at: u64key_id: u32message_number: u32inner_event_json: Stringinner_event_id: StringTrait Implementations
Sourceimpl<UT> ConvertError<UT> for GroupDecryptedResult
impl<UT> ConvertError<UT> for GroupDecryptedResult
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for GroupDecryptedResult
impl<UT> FfiConverter<UT> for GroupDecryptedResult
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for GroupDecryptedResult
impl<UT> Lift<UT> for GroupDecryptedResult
Sourceimpl<UT> LiftRef<UT> for GroupDecryptedResult
impl<UT> LiftRef<UT> for GroupDecryptedResult
Sourceimpl<UT> LiftReturn<UT> for GroupDecryptedResult
impl<UT> LiftReturn<UT> for GroupDecryptedResult
Sourcetype ReturnType = <GroupDecryptedResult as Lift<UT>>::FfiType
type ReturnType = <GroupDecryptedResult as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for GroupDecryptedResult
impl<UT> Lower<UT> for GroupDecryptedResult
type FfiType = <GroupDecryptedResult as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for GroupDecryptedResult
impl<UT> LowerError<UT> for GroupDecryptedResult
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for GroupDecryptedResult
impl<UT> LowerReturn<UT> for GroupDecryptedResult
Sourcetype ReturnType = <GroupDecryptedResult as Lower<UT>>::FfiType
type ReturnType = <GroupDecryptedResult as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for GroupDecryptedResult
impl<UT> TypeId<UT> for GroupDecryptedResult