pub struct PubSubEvent {
pub kind: String,
pub subid: Option<String>,
pub filter_json: Option<String>,
pub event_json: Option<String>,
pub sender_pubkey_hex: Option<String>,
pub content: Option<String>,
pub event_id: Option<String>,
}Expand description
Event emitted by SessionManager for external publish/subscribe handling.
Fields
kind: Stringsubid: Option<String>filter_json: Option<String>event_json: Option<String>sender_pubkey_hex: Option<String>content: Option<String>event_id: Option<String>Trait Implementations
Sourceimpl<UT> ConvertError<UT> for PubSubEvent
impl<UT> ConvertError<UT> for PubSubEvent
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<UT> FfiConverter<UT> for PubSubEvent
impl<UT> FfiConverter<UT> for PubSubEvent
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a MetadataBuffer.
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl<UT> Lift<UT> for PubSubEvent
impl<UT> Lift<UT> for PubSubEvent
Sourceimpl<UT> LiftRef<UT> for PubSubEvent
impl<UT> LiftRef<UT> for PubSubEvent
type LiftType = PubSubEvent
Sourceimpl<UT> LiftReturn<UT> for PubSubEvent
impl<UT> LiftReturn<UT> for PubSubEvent
Sourcetype ReturnType = <PubSubEvent as Lift<UT>>::FfiType
type ReturnType = <PubSubEvent as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
Sourcefn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
Sourcefn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
Sourcefn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for PubSubEvent
impl<UT> Lower<UT> for PubSubEvent
type FfiType = <PubSubEvent as FfiConverter<UT>>::FfiType
fn lower(obj: Self) -> Self::FfiType
fn write(obj: Self, buf: &mut Vec<u8>)
Sourcefn lower_into_rust_buffer(obj: Self) -> RustBuffer
fn lower_into_rust_buffer(obj: Self) -> RustBuffer
Convenience method
Sourceimpl<UT> LowerError<UT> for PubSubEvent
impl<UT> LowerError<UT> for PubSubEvent
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for PubSubEvent
impl<UT> LowerReturn<UT> for PubSubEvent
Sourcetype ReturnType = <PubSubEvent as Lower<UT>>::FfiType
type ReturnType = <PubSubEvent as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for PubSubEvent
impl<UT> TypeId<UT> for PubSubEvent