pub struct InviteHandle { /* private fields */ }Expand description
FFI wrapper for Invite.
Implementations
Sourceimpl InviteHandle
impl InviteHandle
Sourcepub fn create_new(
inviter_pubkey_hex: String,
device_id: Option<String>,
max_uses: Option<u32>,
) -> Result<Arc<Self>, NdrError>
pub fn create_new( inviter_pubkey_hex: String, device_id: Option<String>, max_uses: Option<u32>, ) -> Result<Arc<Self>, NdrError>
Create a new invite.
Sourcepub fn from_event_json(event_json: String) -> Result<Arc<Self>, NdrError>
pub fn from_event_json(event_json: String) -> Result<Arc<Self>, NdrError>
Parse an invite from a Nostr event JSON.
Sourcepub fn deserialize(json: String) -> Result<Arc<Self>, NdrError>
pub fn deserialize(json: String) -> Result<Arc<Self>, NdrError>
Deserialize an invite from JSON.
Sourcepub fn to_url(&self, root: String) -> Result<String, NdrError>
pub fn to_url(&self, root: String) -> Result<String, NdrError>
Convert the invite to a shareable URL.
Sourcepub fn to_event_json(&self) -> Result<String, NdrError>
pub fn to_event_json(&self) -> Result<String, NdrError>
Convert the invite to a Nostr event JSON.
Sourcepub fn serialize(&self) -> Result<String, NdrError>
pub fn serialize(&self) -> Result<String, NdrError>
Serialize the invite to JSON for persistence.
Sourcepub fn accept(
&self,
invitee_pubkey_hex: String,
invitee_privkey_hex: String,
device_id: Option<String>,
) -> Result<InviteAcceptResult, NdrError>
pub fn accept( &self, invitee_pubkey_hex: String, invitee_privkey_hex: String, device_id: Option<String>, ) -> Result<InviteAcceptResult, NdrError>
Accept the invite and create a session.
Sourcepub fn accept_with_owner(
&self,
invitee_pubkey_hex: String,
invitee_privkey_hex: String,
device_id: Option<String>,
owner_pubkey_hex: Option<String>,
) -> Result<InviteAcceptResult, NdrError>
pub fn accept_with_owner( &self, invitee_pubkey_hex: String, invitee_privkey_hex: String, device_id: Option<String>, owner_pubkey_hex: Option<String>, ) -> Result<InviteAcceptResult, NdrError>
Accept the invite as an owner and include the owner pubkey in the response payload.
Sourcepub fn set_purpose(&self, purpose: Option<String>)
pub fn set_purpose(&self, purpose: Option<String>)
Update the invite purpose (e.g. "link").
Sourcepub fn set_owner_pubkey_hex(
&self,
owner_pubkey_hex: Option<String>,
) -> Result<(), NdrError>
pub fn set_owner_pubkey_hex( &self, owner_pubkey_hex: Option<String>, ) -> Result<(), NdrError>
Update the owner pubkey embedded in invite URLs.
Sourcepub fn process_response(
&self,
event_json: String,
inviter_privkey_hex: String,
) -> Result<Option<InviteProcessResult>, NdrError>
pub fn process_response( &self, event_json: String, inviter_privkey_hex: String, ) -> Result<Option<InviteProcessResult>, NdrError>
Process an invite response event and create a session (inviter side).
Returns None if the event is not a valid response for this invite.
Sourcepub fn get_inviter_pubkey_hex(&self) -> String
pub fn get_inviter_pubkey_hex(&self) -> String
Get the inviter’s public key as hex.
Get the shared secret as hex.